@@ -58,9 +58,6 @@
 
 #if defined HAVE_KCRASH
 #include <kcrash.h>
-
-#elif defined USE_BREAKPAD
-    #include "kis_crash_handler.h"
 #elif defined USE_DRMINGW
 namespace
 {
@@ -94,6 +91,10 @@ extern "C" int main(int argc, char **argv)
     // The global initialization of the random generator
     qsrand(time(0));
     bool runningInKDE = !qgetenv("KDE_FULL_SESSION").isEmpty();
+    
+#if defined HAVE_X11 
+    qputenv("QT_QPA_PLATFORM", "xcb"); 
+#endif
 
     /**
      * Disable debug output by default. (krita.input enables tablet debugging.)
@@ -185,10 +186,6 @@ extern "C" int main(int argc, char **argv)
 
 #if defined HAVE_KCRASH
     KCrash::initialize();
-#elif defined USE_BREAKPAD
-    qputenv("KDE_DEBUG", "1");
-    KisCrashHandler crashHandler;
-    Q_UNUSED(crashHandler);
 #elif defined USE_DRMINGW
     tryInitDrMingw();
 #endif
@@ -247,6 +244,10 @@ extern "C" int main(int argc, char **argv)
         return 1;
     }
 
+#if QT_VERSION >= 0x050700
+    app.setAttribute(Qt::AA_CompressHighFrequencyEvents, false);
+#endif
+    
     // Set up remote arguments.
     QObject::connect(&app, SIGNAL(messageReceived(QByteArray,QObject*)),
                      &app, SLOT(remoteArguments(QByteArray,QObject*)));
@@ -255,7 +256,7 @@ extern "C" int main(int argc, char **argv)
                      &app, SLOT(fileOpenRequested(QString)));
 
     int state = app.exec();
-
+    
     return state;
 }
 
