@@ -145,7 +145,7 @@ KisSelectionSP KisSelectionBasedLayer::fetchComposedInternalSelection(const QRec
 
     KisSelectionSP tempSelection = m_d->selection;
 
-    lockTemporaryTarget();
+    KisIndirectPaintingSupport::ReadLocker l(this);
 
     if (hasTemporaryTarget()) {
         /**
@@ -159,8 +159,6 @@ KisSelectionSP KisSelectionBasedLayer::fetchComposedInternalSelection(const QRec
         gc2.bitBlt(rect.topLeft(), temporaryTarget(), rect);
     }
 
-    unlockTemporaryTarget();
-
     return tempSelection;
 }
 
