@@ -127,6 +127,7 @@
 #include "kis_icon_utils.h"
 #include "kis_guides_manager.h"
 #include "kis_derived_resources.h"
+#include "dialogs/kis_delayed_save_dialog.h"
 
 
 class BlockingUserInputEventFilter : public QObject
@@ -150,7 +151,7 @@ class KisViewManager::KisViewManagerPrivate
 
 public:
 
-    KisViewManagerPrivate(KisViewManager *_q, QWidget *_q_parent)
+    KisViewManagerPrivate(KisViewManager *_q, KActionCollection *_actionCollection, QWidget *_q_parent)
         : filterManager(_q)
         , createTemplate(0)
         , saveIncremental(0)
@@ -174,13 +175,14 @@ public:
         , gridManager(_q)
         , canvasControlsManager(_q)
         , paintingAssistantsManager(_q)
-        , actionManager(_q)
+        , actionManager(_q, _actionCollection)
         , mainWindow(0)
         , showFloatingMessage(true)
         , currentImageView(0)
         , canvasResourceProvider(_q)
         , canvasResourceManager()
         , guiUpdateCompressor(30, KisSignalCompressor::POSTPONE, _q)
+        , actionCollection(_actionCollection)
         , mirrorManager(_q)
         , inputManager(_q)
         , actionAuthor(0)
@@ -242,11 +244,13 @@ public:
     KSelectAction *actionAuthor; // Select action for author profile.
 
     QByteArray canvasState;
+
+    bool blockUntillOperationsFinishedImpl(KisImageSP image, bool force);
 };
 
 
 KisViewManager::KisViewManager(QWidget *parent, KActionCollection *_actionCollection)
-    : d(new KisViewManagerPrivate(this, parent))
+    : d(new KisViewManagerPrivate(this, _actionCollection, parent))
 {
     d->actionCollection = _actionCollection;
     d->mainWindow = dynamic_cast<QMainWindow*>(parent);
@@ -744,6 +748,26 @@ int KisViewManager::viewCount() const
     return 0;
 }
 
+bool KisViewManager::KisViewManagerPrivate::blockUntillOperationsFinishedImpl(KisImageSP image, bool force)
+{
+    const int busyWaitDelay = 1000;
+    KisDelayedSaveDialog dialog(image, !force ? KisDelayedSaveDialog::GeneralDialog : KisDelayedSaveDialog::ForcedDialog, busyWaitDelay, mainWindow);
+    dialog.blockIfImageIsBusy();
+
+    return dialog.result() == QDialog::Accepted;
+}
+
+
+bool KisViewManager::blockUntillOperationsFinished(KisImageSP image)
+{
+    return d->blockUntillOperationsFinishedImpl(image, false);
+}
+
+void KisViewManager::blockUntillOperationsFinishedForced(KisImageSP image)
+{
+    d->blockUntillOperationsFinishedImpl(image, true);
+}
+
 void KisViewManager::slotCreateTemplate()
 {
     if (!document()) return;
@@ -1060,9 +1084,18 @@ void KisViewManager::switchCanvasOnly(bool toggled)
 
     if (cfg.hideDockersFullscreen()) {
         KisAction* action = qobject_cast<KisAction*>(main->actionCollection()->action("view_toggledockers"));
-        action->setCheckable(true);
-        if (action && action->isChecked() == toggled) {
-            action->setChecked(!toggled);
+        if (action) {
+            action->setCheckable(true);
+            if (toggled) {
+                if (action->isChecked()) {
+                    cfg.setShowDockers(action->isChecked());
+                    action->setChecked(false);
+                } else {
+                    cfg.setShowDockers(false);
+                }
+            } else {
+                action->setChecked(cfg.showDockers());
+            }
         }
     }
 
@@ -1261,5 +1294,3 @@ void KisViewManager::slotUpdateAuthorProfileActions()
         d->actionAuthor->setCurrentItem(0);
     }
 }
-
-
