@@ -224,7 +224,7 @@ bool KisInputManager::compressMoveEventCommon(Event *event)
      */
     static_assert(std::is_same<Event, QMouseEvent>::value ||
                   std::is_same<Event, QTabletEvent>::value,
-                  "event should a mouse or a tablet event");
+                  "event should be a mouse or a tablet event");
 
     bool retval = false;
 
@@ -559,9 +559,9 @@ QTouchEvent *KisInputManager::lastTouchEvent() const
 
 void KisInputManager::slotToolChanged()
 {
-    auto toolManager = KoToolManager::instance();
-    auto tool = toolManager->toolById(canvas(), toolManager->activeToolId());
-    if (tool->isInTextMode()) {
+    KoToolManager *toolManager = KoToolManager::instance();
+    KoToolBase *tool = toolManager->toolById(canvas(), toolManager->activeToolId());
+    if (tool && tool->isInTextMode()) {
         d->forwardAllEventsToTool = true;
         d->matcher.suppressAllActions(true);
     } else {
