@@ -288,6 +288,9 @@ public:
     bool showDockerTitleBars(bool defaultValue = false) const;
     void setShowDockerTitleBars(const bool value) const;
 
+    bool showDockers(bool defaultValue = false) const;
+    void setShowDockers(const bool value) const;
+
     bool showStatusBar(bool defaultValue = false) const;
     void setShowStatusBar(const bool value) const;
 
@@ -494,6 +497,8 @@ public:
     QString brushHudSetting(bool defaultValue = false) const;
     void setBrushHudSetting(const QString &value) const;
 
+    bool disableColorizeMaskFeature() const;
+
     template<class T>
     void writeEntry(const QString& name, const T& value) {
         m_cfg.writeEntry(name, value);
