@@ -386,7 +386,6 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
     action = new QWidgetAction(this);
     KisActionRegistry::instance()->propertizeAction("previous_preset", action);
     view->actionCollection()->addAction("previous_preset", action);
-
     connect(action, SIGNAL(triggered()), this, SLOT(slotSwitchToPreviousPreset()));
 
     if (!cfg.toolOptionsInDocker()) {
@@ -473,10 +472,6 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
 
     connect(m_hMirrorAction        , SIGNAL(toggled(bool))                    , SLOT(slotHorizontalMirrorChanged(bool)));
     connect(m_vMirrorAction        , SIGNAL(toggled(bool))                    , SLOT(slotVerticalMirrorChanged(bool)));
-
-
-
-
     connect(m_reloadAction         , SIGNAL(triggered())                        , SLOT(slotReloadPreset()));
 
     connect(m_sliderChooser[0]->getWidget<KisDoubleSliderSpinBox>("opacity"), SIGNAL(valueChanged(qreal)), SLOT(slotSlider1Changed()));
@@ -537,7 +532,7 @@ void KisPaintopBox::restoreResource(KoResource* resource)
 {
     KisPaintOpPreset* preset = dynamic_cast<KisPaintOpPreset*>(resource);
     if (preset) {
-        setCurrentPaintop(preset->paintOp(), preset);
+        setCurrentPaintop(preset);
 
         m_presetsPopup->setPresetImage(preset->image());
         m_presetsPopup->resourceSelected(resource);
@@ -554,30 +549,38 @@ void KisPaintopBox::newOptionWidgets(const QList<QPointer<QWidget> > &optionWidg
 void KisPaintopBox::resourceSelected(KoResource* resource)
 {
     KisPaintOpPreset* preset = dynamic_cast<KisPaintOpPreset*>(resource);
-    if (preset) {
+    if (preset && preset != m_resourceProvider->currentPreset()) {
         if (!preset->settings()->isLoadable())
             return;
 
-        setCurrentPaintopAndReload(preset->paintOp(), preset);
+        if (!m_dirtyPresetsEnabled) {
+            KisSignalsBlocker blocker(m_optionWidget);
+            if (!preset->load()) {
+                warnKrita << "failed to load the preset.";
+            }
+        }
+
+        setCurrentPaintop(preset);
+
         m_presetsPopup->setPresetImage(preset->image());
         m_presetsPopup->resourceSelected(resource);
     }
 }
 
-void KisPaintopBox::setCurrentPaintopAndReload(const KoID& paintop, KisPaintOpPresetSP preset)
+void KisPaintopBox::setCurrentPaintop(const KoID& paintop)
 {
-    if (!m_dirtyPresetsEnabled) {
-        KisSignalsBlocker blocker(m_optionWidget);
-        if (!preset->load()) {
-            warnKrita << "failed to load the preset.";
-        }
-    }
-
-    setCurrentPaintop(paintop, preset);
+    KisPaintOpPresetSP preset = activePreset(paintop);
+    Q_ASSERT(preset && preset->settings());
+    setCurrentPaintop(preset);
 }
 
-void KisPaintopBox::setCurrentPaintop(const KoID& paintop, KisPaintOpPresetSP preset)
+void KisPaintopBox::setCurrentPaintop(KisPaintOpPresetSP preset)
 {
+    if (preset == m_resourceProvider->currentPreset()) {
+        return;
+    }
+    Q_ASSERT(preset);
+    const KoID& paintop = preset->paintOp();
     m_presetConnections.clear();
 
     if (m_resourceProvider->currentPreset()) {
@@ -593,9 +596,6 @@ void KisPaintopBox::setCurrentPaintop(const KoID& paintop, KisPaintOpPresetSP pr
         m_tabletToolMap[m_currTabletToolID].paintOpID = m_resourceProvider->currentPreset()->paintOp();
     }
 
-    preset = (!preset) ? activePreset(paintop) : preset;
-    Q_ASSERT(preset && preset->settings());
-
     if (!m_paintopOptionWidgets.contains(paintop))
         m_paintopOptionWidgets[paintop] = KisPaintOpRegistry::instance()->get(paintop.id())->createConfigWidget(this);
 
@@ -751,11 +751,16 @@ void KisPaintopBox::slotInputDeviceChanged(const KoInputDevice& inputDevice)
             preset = rserver->resourceByName("Basic_tip_default");
         }
         if (preset) {
-            setCurrentPaintop(preset->paintOp(), preset);
+            setCurrentPaintop(preset);
         }
     }
     else {
-        setCurrentPaintop(toolData->paintOpID, toolData->preset);
+        if (toolData->preset) {
+            setCurrentPaintop(toolData->preset);
+        }
+        else {
+            setCurrentPaintop(toolData->paintOpID);
+        }
     }
 
     m_currTabletToolID = TabletToolID(inputDevice);
@@ -937,12 +942,12 @@ void KisPaintopBox::slotToggleEraseMode(bool checked)
         qreal newSize = checked ? settings->savedEraserSize() : settings->savedBrushSize();
         m_resourceProvider->setSize(newSize);
     }
-   if (m_eraserBrushOpacityEnabled) {
+   if (oldEraserMode != checked && m_eraserBrushOpacityEnabled) {
         const qreal currentOpacity = m_resourceProvider->opacity();
 
         KisPaintOpSettingsSP settings = m_resourceProvider->currentPreset()->settings();
 
-        // remember brush opacity. set the eraser opacity to the normal brush size if not set
+        // remember brush opacity. set the eraser opacity to the normal brush opacity if not set
         if (checked) {
             settings->setSavedBrushOpacity(currentOpacity);
             if (qFuzzyIsNull(settings->savedEraserOpacity())) {
@@ -1101,7 +1106,7 @@ void KisPaintopBox::slotNextFavoritePreset()
 void KisPaintopBox::slotSwitchToPreviousPreset()
 {
     if (m_resourceProvider->previousPreset()) {
-        setCurrentPaintop(m_resourceProvider->previousPreset()->paintOp(), m_resourceProvider->previousPreset());
+        setCurrentPaintop(m_resourceProvider->previousPreset());
     }
 }
 
@@ -1144,9 +1149,21 @@ void KisPaintopBox::slotReloadPreset()
 }
 void KisPaintopBox::slotGuiChangedCurrentPreset() // Called only when UI is changed and not when preset is changed
 {
-    m_optionWidget->writeConfigurationSafe(const_cast<KisPaintOpSettings*>(m_resourceProvider->currentPreset()->settings().data()));
+    KisPaintOpPresetSP preset = m_resourceProvider->currentPreset();
 
-    //m_presetsPopup->resourceSelected(m_resourceProvider->currentPreset().data());
+    {
+        /**
+         * Here we postpone all the settings updates events until thye entire writing
+         * operation will be finished. As soon as it is finished, the updates will be
+         * emitted happily (if there were any).
+         */
+
+        KisPaintOpPreset::UpdatedPostponer postponer(preset.data());
+        m_optionWidget->writeConfigurationSafe(const_cast<KisPaintOpSettings*>(preset->settings().data()));
+    }
+
+    // we should also update the preset strip to update the status of the "dirty" mark
+    m_presetsPopup->resourceSelected(m_resourceProvider->currentPreset().data());
 
     // TODO!!!!!!!!
     //m_presetsPopup->updateViewSettings();
