@@ -40,6 +40,10 @@
 
 #include <assert.h>
 
+#if defined(KCONFIG_BEFORE_5_24)
+# define authorizeAction authorizeKAction
+#endif
+
 class KXMLGUIClientPrivate
 {
 public:
@@ -429,7 +433,7 @@ bool KXMLGUIClientPrivate::mergeXML(QDomElement &base, QDomElement &additive, KA
             if (equalstr(tag, tagAction)) {
                 const QString name =  e.attribute(attrName);
                 if (!actionCollection->action(name) ||
-                        !KAuthorized::authorizeKAction(name)) {
+                        !KAuthorized::authorizeAction(name)) {
                     // remove this child as we aren't using it
                     base.removeChild(e);
                     continue;
