@@ -594,7 +594,7 @@ void KisRulerAssistantTool::paint(QPainter& _gc, const KoViewConverter &_convert
 
     // TODO: too  many Q_FOREACH loops going through all assistants. Condense this to one to be a little more performant
 
-    // render handles for the asssistant
+    // Draw corner and middle perspective nodes
     Q_FOREACH (KisPaintingAssistantSP assistant, m_canvas->paintingAssistantsDecoration()->assistants()) {
         Q_FOREACH (const KisPaintingAssistantHandleSP handle, m_handles) {
             QRectF ellipse(_converter.documentToView(*handle) -  QPointF(6, 6), QSizeF(12, 12));
@@ -628,6 +628,7 @@ void KisRulerAssistantTool::paint(QPainter& _gc, const KoViewConverter &_convert
 
 
     Q_FOREACH (KisPaintingAssistantSP assistant, m_canvas->paintingAssistantsDecoration()->assistants()) {
+        // Draw middle perspective handles
         if(assistant->id()=="perspective") {
             assistant->findHandleLocation();
             QPointF topMiddle, bottomMiddle, rightMiddle, leftMiddle;
@@ -663,7 +664,7 @@ void KisRulerAssistantTool::paint(QPainter& _gc, const KoViewConverter &_convert
         }
     }
 
-
+    // Draw the assistant widget
     Q_FOREACH (const KisPaintingAssistantSP assistant, m_canvas->paintingAssistantsDecoration()->assistants()) {
 
 
@@ -893,10 +894,17 @@ QWidget *KisRulerAssistantTool::createOptionWidget()
         m_options.loadButton->setIcon(KisIconUtils::loadIcon("document-open"));
         m_options.saveButton->setIcon(KisIconUtils::loadIcon("document-save"));
         m_options.deleteButton->setIcon(KisIconUtils::loadIcon("edit-delete"));
+
+        QList<KoID> assistants;
         Q_FOREACH (const QString& key, KisPaintingAssistantFactoryRegistry::instance()->keys()) {
             QString name = KisPaintingAssistantFactoryRegistry::instance()->get(key)->name();
-            m_options.comboBox->addItem(name, key);
+            assistants << KoID(key, name);
         }
+        qSort(assistants.begin(), assistants.end(), KoID::compareNames);
+        Q_FOREACH(const KoID &id, assistants) {
+            m_options.comboBox->addItem(id.name(), id.id());
+        }
+
         connect(m_options.saveButton, SIGNAL(clicked()), SLOT(saveAssistants()));
         connect(m_options.loadButton, SIGNAL(clicked()), SLOT(loadAssistants()));
         connect(m_options.deleteButton, SIGNAL(clicked()), SLOT(removeAllAssistants()));
