@@ -131,7 +131,7 @@ DlgAnimationRenderer::DlgAnimationRenderer(KisDocument *doc, QWidget *parent)
 
     connect(m_page->grpRender, SIGNAL(toggled(bool)), this, SLOT(toggleSequenceType(bool)));
     connect(m_page->bnExportOptions, SIGNAL(clicked()), this, SLOT(sequenceMimeTypeSelected()));
-    connect(m_page->bnRenderOptions, SIGNAL(clicked()), this, SLOT(selectRenderType()));
+    connect(m_page->bnRenderOptions, SIGNAL(clicked()), this, SLOT(selectRenderOptions()));
 
     m_page->ffmpegLocation->setFileName(findFFMpeg());
     m_page->ffmpegLocation->setMode(KoFileDialog::OpenFile);
@@ -140,8 +140,7 @@ DlgAnimationRenderer::DlgAnimationRenderer(KisDocument *doc, QWidget *parent)
     m_page->grpRender->setChecked(cfg.readEntry<bool>("AnimationRenderer/render_animation", false));
     m_page->chkDeleteSequence->setChecked(cfg.readEntry<bool>("AnimationRenderer/delete_sequence", false));
     m_page->cmbRenderType->setCurrentIndex(cfg.readEntry<int>("AnimationRenderer/render_type", 0));
-
-
+    connect(m_page->cmbRenderType, SIGNAL(currentIndexChanged(int)), this, SLOT(selectRenderType(int)));
 }
 
 DlgAnimationRenderer::~DlgAnimationRenderer()
@@ -203,6 +202,7 @@ KisPropertiesConfigurationSP DlgAnimationRenderer::getFrameExportConfiguration()
         cfg->setProperty("first_frame", m_page->intStart->value());
         cfg->setProperty("last_frame", m_page->intEnd->value());
         cfg->setProperty("sequence_start", m_page->sequenceStart->value());
+        cfg->setProperty("ffmpeg_path", m_page->ffmpegLocation->fileName());
 
         return m_frameExportConfigWidget->configuration();
     }
@@ -220,7 +220,12 @@ KisPropertiesConfigurationSP DlgAnimationRenderer::getVideoConfiguration() const
         return 0;
     }
     KisPropertiesConfigurationSP cfg = new KisPropertiesConfiguration();
-    cfg->setProperty("filename", m_page->videoFilename->fileName());
+    QString filename = m_page->videoFilename->fileName();
+    if (QFileInfo(filename).completeSuffix().isEmpty()) {
+        QString mimetype = m_page->cmbRenderType->itemData(m_page->cmbRenderType->currentIndex()).toString();
+        filename += "." + KisMimeDatabase::suffixesForMimeType(mimetype).first();
+    }
+    cfg->setProperty("filename", filename);
     cfg->setProperty("delete_sequence", m_page->chkDeleteSequence->isChecked());
     return cfg;
 }
@@ -260,7 +265,19 @@ QSharedPointer<KisImportExportFilter> DlgAnimationRenderer::encoderFilter() cons
     return QSharedPointer<KisImportExportFilter>(0);
 }
 
-void DlgAnimationRenderer::selectRenderType()
+void DlgAnimationRenderer::selectRenderType(int index)
+{
+    if (index >= m_renderFilters.size()) return;
+    QString mimetype = m_page->cmbRenderType->itemData(index).toString();
+
+    if (!m_page->videoFilename->fileName().isEmpty() && QFileInfo(m_page->videoFilename->fileName()).completeBaseName() != m_defaultFileName) {
+        m_defaultFileName = QFileInfo(m_page->videoFilename->fileName()).completeBaseName();
+    }
+    m_page->videoFilename->setMimeTypeFilters(QStringList() << mimetype, mimetype);
+    m_page->videoFilename->setFileName(m_defaultFileName + "." + KisMimeDatabase::suffixesForMimeType(mimetype).first());
+}
+
+void DlgAnimationRenderer::selectRenderOptions()
 {
     int index = m_page->cmbRenderType->currentIndex();
 
@@ -273,13 +290,6 @@ void DlgAnimationRenderer::selectRenderType()
 
     QSharedPointer<KisImportExportFilter> filter = m_renderFilters[index];
     QString mimetype = m_page->cmbRenderType->itemData(index).toString();
-
-    if (!m_page->videoFilename->fileName().isEmpty() && QFileInfo(m_page->videoFilename->fileName()).completeBaseName() != m_defaultFileName) {
-        m_defaultFileName = QFileInfo(m_page->videoFilename->fileName()).completeBaseName();
-    }
-    m_page->videoFilename->setMimeTypeFilters(QStringList() << mimetype, mimetype);
-    m_page->videoFilename->setFileName(m_defaultFileName + "." + KisMimeDatabase::suffixesForMimeType(mimetype).first());
-
     if (filter) {
         m_encoderConfigWidget = filter->createConfigurationWidget(0, KisDocument::nativeFormatMimeType(), mimetype.toLatin1());
         if (m_encoderConfigWidget) {
@@ -298,6 +308,7 @@ void DlgAnimationRenderer::selectRenderType()
     else {
         m_encoderConfigWidget = 0;
     }
+
 }
 
 void DlgAnimationRenderer::toggleSequenceType(bool toggle)
